@@ -1,12 +1,10 @@
 package Dancer2::Plugin::Minion;
-
+$Dancer2::Plugin::Minion::VERSION = '1.0.0';
 # ABSTRACT: Use the Minion job queue in your Dancer2 apps.
 
 use Dancer2::Plugin;
 use Minion;
 
-our $VERSION = '0.3.3';
-
 plugin_keywords qw(
     minion
     add_task
@@ -68,9 +66,11 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Dancer2::Plugin::Minion - Easy access to Minion job queue in your Dancer2 
+Dancer2::Plugin::Minion - Easy access to Minion job queue in your Dancer2
 applications
 
 =head1 SYNOPSIS
@@ -87,14 +87,14 @@ applications
         });
     };
 
-    get '/another-route' => sub {
-        my $id = enqueue(add => [1, 1]);
-        # Do something with $id
+    get '/start-job' => sub {
+        my $id = enqueue( add => [1, 1] );
+        return "Started job ID $id";
     };
 
-    get '/yet-another-route' => sub {
-        # Get a job ID, then...
-        my $result = minion->job($id)->info->{result};
+    get '/job-results/:job_id' => sub {
+        my $id     = route_parameters->get( 'job_id' ) // 0;
+        my $result = minion->job( $id )->info->{ result };
     };
 
     build {
@@ -111,11 +111,11 @@ applications
 =head1 DESCRIPTION
 
 C<Dancer2::Plugin::Minion> makes it easy to add a job queue to any of your
-L<Dancer2> applications. The queue is powered by L<Minion> and uses a 
+L<Dancer2> applications. The queue is powered by L<Minion> and uses a
 backend of your choosing, such as PostgreSQL or SQLite.
 
 The plugin lazily instantiates a Minion object, which is accessible via the
-C<minion> keyword. Any method, attribute, or event you need in Minion is 
+C<minion> keyword. Any method, attribute, or event you need in Minion is
 available via this keyword. Additionally, C<add_task> and C<enqueue> keywords
 are available to make it convenient to add and start new queued jobs.
 
@@ -138,13 +138,13 @@ for details
 
 =head2 add_task()
 
-Keyword/shortcut for C<< minion->add_task() >>. See 
+Keyword/shortcut for C<< minion->add_task() >>. See
 L<Minion's add_task() documentation|Minion/add_task> for
 more information.
 
 =head2 enqueue()
 
-Keyword/shortcut for C<< minion->enqueue() >>. 
+Keyword/shortcut for C<< minion->enqueue() >>.
 See L<Minion's enqueue() documentation|Minion/enqueue1>
 for more information.
 
@@ -157,12 +157,12 @@ slash in your mount path!
 
 You can optionally pass in an absolute URL to act as the "return to" link. The url must
 be absolute or else it will be made relative to the admin UI, which is probably
-not what you want. For example: 
+not what you want. For example:
 C<< mount '/dashboard/' => minion_app( 'http://localhost:5000/foo' )->start; >>
 
 =head1 RUNNING JOBS
 
-You will need to create a Minion worker if you want to be able to run your 
+You will need to create a Minion worker if you want to be able to run your
 queued jobs. Thankfully, you can write a minimal worker with just a few
 lines of code:
 
@@ -170,15 +170,17 @@ lines of code:
 
     use Dancer2;
     use Dancer2::Plugin::Minion;
-    use MyJobLib;
 
-    minion->add_task( my_job_1 => MyJobLib::job1());
+    minion->add_task( add => sub {
+        my ( $job, $first, $second ) = @_;
+        $job->finish( $first + $second );
+    });
 
     my $worker = minion->worker;
     $worker->run;
 
-By using C<Dancer2::Plugin::Minion>, your worker will be configured with 
-the settings provided in your F<config.yml> file. See L<Minion::Worker> 
+By using C<Dancer2::Plugin::Minion>, your worker will be configured with
+the settings provided in your F<config.yml> file. See L<Minion::Worker>
 for more information.
 
 =head1 SEE ALSO
@@ -193,7 +195,7 @@ for more information.
 
 =head1 AUTHOR
 
-Jason A. Crome C< cromedome AT cpan DOT org >
+Jason A. Crome C< cpan AT jason DOT cromedome DOT dev >
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -207,16 +209,20 @@ led to the improvement of this plugin:
 =over 4
 
 =item * Gabor Szabo
+
 =item * Joel Berger
+
 =item * Slaven Rezić
 
+=item * Julien Fiegehenn
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2020, Clearbuilt Technologies.
+Copyright (c) 2024, Jason A. Crome
 
-This is free software; you can redistribute it and/or modify it under 
+This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
